<?php

namespace LitePress\LP_Translate\Api;

use LitePress\User_Module\User_Module;
use WP_Http;
use WP_REST_Request;
use WP_REST_Response;
use function LitePress\LP_Translate\get_project_for_cloud;

/**
 * 项目相关的 API
 */
class Project extends Base {

    public function __construct() {
        add_action( 'rest_api_init', array( $this, 'route' ) );
    }

    public function route() {
        /**
         * 为某个项目申请审批者权限
         */
        register_rest_route( self::namespace, 'project/approve', array(
            'methods'             => 'POST',
            'callback'            => array( $this, 'apply_approve' ),
            'permission_callback' => '__return_true',
        ) );
    }

    public function apply_approve( WP_REST_Request $request ): WP_REST_Response {
        $domain = sanitize_text_field( $request->get_param( 'domain' ) );

        if ( empty( $domain ) ) {
            return $this->error( 'Domain 字段不可为空' );
        }

        $user = User_Module::get_instance()->get_user_info();

        if ( empty( $user ) ) {
            return $this->error( "请先登录 litepress.cn 账号" );
        }

        // 获取项目 path
        $project = get_project_for_cloud( $domain );
        if ( empty( $project ) ) {
            return $this->error( '该项目未收录，请先申请托管' );
        }
        $path = $project->get_path();

        // 请求接口获取用户所管理的项目
        $args   = array(
            'headers' => array(
                'Authorization' => "Bearer {$user->get_token()}",
            ),
            'body'    => array(
                'path' => $path,
            )
        );
        $result = wp_remote_post( 'https://api.litepress.cn/translate/projects/approve', $args );

        $status_code = wp_remote_retrieve_response_code( $result );
        if ( WP_Http::OK !== $status_code ) {
            // 如果状态码为 403 需要清除一下本地的登陆状态，可能是 Token 过期了
            if ( WP_Http::FORBIDDEN === $status_code ) {
                User_Module::get_instance()->clear_login_status();

                return $this->error( "LP Translate 的登陆状态已过期" );
            }

            return $this->error( "litepress.cn 返回了意料之外的状态码：{$status_code}" );
        }

        if ( is_wp_error( $result ) ) {
            return $this->error( "litepress.cn 返回了错误消息：{$result->get_error_message()}" );
        }

        $body = wp_remote_retrieve_body( $result );

        $projects = json_decode( $body, true );
        if ( isset( $projects['error'] ) ) {
            return $this->error( "从 litepress.cn 获取当前管理的项目时接口返回了错误消息：{$projects['error']}" );
        }

        return $this->success( $projects['message'] );
    }

}
