<?php

namespace LitePress\LP_Translate;

use LitePress\User_Module\User_Module;

function get_cloud_projects() {
    if ( ! User_Module::get_instance()->is_logged() ) {
        return false;
    }

    $user = User_Module::get_instance()->get_user_info();

    return get_transient( "lp_cloud_projects_by_{$user->get_login_name()}" );
}

/**
 * 判断某个项目是否存在于云端
 *
 * @param $domain
 *
 * @return bool
 */
function exist_cloud( $domain ): bool {
    $cloud_projects = get_cloud_projects();
    if ( empty( $cloud_projects ) ) {
        return false;
    }

    return isset( $cloud_projects[ $domain ] );
}

/**
 * 从云端获取某个项目的详情
 *
 * @return Project|bool
 */
function get_project_for_cloud( $domain ) {
    $cloud_projects = get_cloud_projects();
    if ( empty( $cloud_projects ) || ! isset( $cloud_projects[ $domain ] ) ) {
        return false;
    }

    return $cloud_projects[ $domain ];
}

/**
 * 检查权限
 *
 * @return false|mixed
 */
function can( $action, $domain ): bool {
    $cloud_projects = get_cloud_projects();
    if ( empty( $cloud_projects ) || ! isset( $cloud_projects[ $domain ] ) ) {
        return false;
    }

    /**
     * @var $project Project
     */
    $project = $cloud_projects[ $domain ];

    return $action === $project->get_permission();
}

/**
 * 获取某个本地的插件、主题的详细信息
 *
 * @param $type string 类型 plugin 或 theme
 * @param $index string 对于插件来说通常类似 a/a.php，对于主题来说通常是其 textdomain
 *
 * @return Project
 */
function get_local_project_info( string $type, string $index ): Project {
    $project = new Project();

    if ( 'plugin' === $type ) {
        $path = WP_CONTENT_DIR . "/plugins/{$index}";
        if ( file_exists( $path ) ) {
            if ( ! function_exists( 'get_plugin_data' ) ) {
                require ABSPATH . '/wp-admin/includes/plugin.php';
            }

            $data = get_plugin_data( $path );
            if ( ! empty( $data ) ) {
                $project->set_name( $data['Name'] );
                $project->set_version( $data['Version'] );
                $project->set_textdomain( $data['TextDomain'] );
            }
        }
    } else {
        if ( ! function_exists( 'wp_get_theme' ) ) {
            require ABSPATH . '/wp-admin/includes/theme.php';
        }

        $data = wp_get_theme( $index );
        if ( ! empty( $data ) ) {
            $project->set_name( $data->get( 'Name' ) );
            $project->set_version( $data->get( 'Version' ) );
            $project->set_textdomain( $index );
        }
    }

    return $project;
}

/**
 * 从 referer 中提取查询参数并保存到数组中
 */
function get_query_for_referer( $key = '' ) {
    $referer = urldecode( $_SERVER['HTTP_REFERER'] );

    list( $host, $query ) = explode( '?', $referer );
    if ( empty( $query ) ) {
        return false;
    }

    $query_list = explode( '&', $query );

    $query_map = array();
    foreach ( $query_list as $item ) {
        list( $k, $v ) = explode( '=', $item );
        $query_map[ $k ] = $v;
    }

    return empty( $key ) ? $query_map : ( $query_map[ $key ] ?? '' );
}
